variantreviewparty
""""""""""""""""""

|GitHub release| |Generic badge| |PyPI version variantreviewparty|

.. |GitHub release| image:: https://img.shields.io/github/release/broadinstitute/variantreviewparty.svg
   :target: https://github.com/broadinstitute/variantreviewparty/releases/

.. |Generic badge| image:: https://img.shields.io/badge/Docker-v0.0.1-blue.svg
   :target: https://console.cloud.google.com/gcr/images/broad-dsp-lrma/US/lr-variantreviewparty

.. |PyPI version variantreviewparty| image:: https://img.shields.io/pypi/v/variantreviewparty.svg
   :target: https://pypi.python.org/pypi/variantreviewparty/

VariantReviewParty is a python library for viewing read level data spanning variants across thousands of samples.

Documentation for the ``VariantReviewParty`` API can be found on the `documentation page <https://broadinstitute.github.io/variantreviewparty/>`_.

Installation
------------

``pip`` is recommended for VariantReviewParty installation.

::

   pip install variantreviewparty

For a pre-built version including all dependencies, access our Docker image.

::

   git clone https://github.com/broadinstitute/variantreviewparty.git
   pip install -e variantreviewparty/

Getting help
------------

If you encounter bugs or have questions/comments/concerns, please file an issue on our `Github page <https://github.com/broadinstitute/variantreviewparty/issues>`_.

Developers' guide
-----------------

For information on contributing to VariantReviewParty development, visit our `developer documentation <DEVELOP.md>`_.
